@@ -20,8 +20,9 @@ mkdir linien
 echo 'installing pyrp3...'
 # install pyrp3
 cd /tmp/linien
-git clone https://github.com/hermitdemschoenenleben/pyrp3.git
+git clone https://github.com/linien-org/pyrp3.git
 cd pyrp3
+git checkout f13da68d825ede3091a082edf99339c5ed736bd2
 python3 setup.py install
 
 echo 'building monitor...'
@@ -35,8 +36,9 @@ rm -R /tmp/linien
 
 # https://github.com/RedPitaya/RedPitaya/issues/205
 echo 'building ethernet blinking fix'
-git clone https://github.com/hermitdemschoenenleben/mdio-tool.git
+git clone https://github.com/linien-org/mdio-tool.git
 cd mdio-tool
+git checkout 72bd5a915ff046a59ce4303c8de672e77622a86c
 cmake .
 make
 rm -f /usr/bin/mdio-tool
