@@ -1,4 +1,4 @@
 #!/bin/bash
 
 screen -X -S linien-server quit
-bash linien_start_ethernet_blinking
\ No newline at end of file
+bash linien_start_ethernet_blinking.sh
\ No newline at end of file
